@@ -1,8 +1,6 @@
 #' @keywords internal
 .cor_test_blomqvist <- function(data, x, y, ci = 0.95, ...) {
-  if (!requireNamespace("wdm", quietly = TRUE)) {
-    stop("Package `wdm` required for 'blomqvist' correlations. Please install it by running `install.packages('wdm').", call. = FALSE)
-  }
+  insight::check_if_installed("wdm", "for 'blomqvist' correlations")
 
   var_x <- .complete_variable_x(data, x, y)
   var_y <- .complete_variable_y(data, x, y)
