@@ -114,21 +114,18 @@ as.list.easycorrelation <- function(x, cols = NULL, redundant = FALSE, ...) {
 # @examples
 # insight::standardize_names(correlation(mtcars[1:4], method = "kendall"))
 # insight::standardize_names(correlation(mtcars[1:4], method = "kendall"), style = "broom")
-# correlation(mtcars[1:4], method = "kendall", standardize_names = T)
+# correlation(mtcars[1:4], method = "kendall", standardize_names = TRUE)
 #' @importFrom insight standardize_names
 #' @export
 standardize_names.easycorrelation <- function(data, ...) {
   ori <- data
-  names(data)[names(data) == datawizard::data_findcols(data, "rho|tau")] <- "r"
+  names(data)[names(data) == datawizard::data_find(data, select = "(rho|tau)", regex = TRUE, verbose = FALSE)] <- "r"
   data <- insight::standardize_names(as.data.frame(data), ...)
   class(data) <- class(ori)
   data
 }
 
 
-
-
-
 # Internals ---------------------------------------------------------------
 
 #' @keywords internal
